# ruthie

[![Current Release](https://img.shields.io/github/release/bitbar/ruthie.svg)](releases)
[![License: ISC](https://img.shields.io/badge/License-ISC-blue.svg)](LICENSE.md)

Run Unit Tests Harmoniously Incredibly Easy

This repo contains _ruthie_ which is the Unittests runner.

## Installation

TODO

## Usage

TODO

## License

This project is licensed under the ISC License - see the [LICENSE](LICENSE) file for details.
